==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ACmpleBinop.h <==
// public final class soot.jimple.parser.node.ACmpleBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fb62b571c38d6640 soot_jimple_parser_node_ACmpleBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpleBinop_H_
#define _JC_soot_jimple_parser_node_ACmpleBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmple$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpleBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpleBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpleBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpleBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpleBinop$refs	_jc_soot_jimple_parser_node_ACmpleBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpleBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpleBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpleBinop$object	_jc_soot_jimple_parser_node_ACmpleBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpleBinop$vmethods	_jc_soot_jimple_parser_node_ACmpleBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpleBinop$vtable	_jc_soot_jimple_parser_node_ACmpleBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpleBinop$vtype	_jc_soot_jimple_parser_node_ACmpleBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpleBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpleBinop$method$_init$5d04d886763d6058(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_TCmple$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpleBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpleBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *);
extern struct _jc_soot_jimple_parser_node_TCmple$object *_jc_soot_jimple_parser_node_ACmpleBinop$method$getCmple$62c946aa52c39c95(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpleBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpleBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpleBinop$method$setCmple$47961de99a6cbeff(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_TCmple$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpleBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$getCmple$62c946aa52c39c95;
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$setCmple$47961de99a6cbeff;
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpleBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *);
	struct _jc_soot_jimple_parser_node_TCmple$object	*(*getCmple$62c946aa52c39c95)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setCmple$47961de99a6cbeff)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_TCmple$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpleBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpleBinop$vmethods	soot_jimple_parser_node_ACmpleBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpleBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpleBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpleBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmple$object	*__5fcmple__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpleBinop$refs {
    _jc_soot_jimple_parser_node_ACmpleBinop$sub_refs	soot_jimple_parser_node_ACmpleBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpleBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpleBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpleBinop$sub_nonrefs	soot_jimple_parser_node_ACmpleBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpleBinop$object {
	_jc_soot_jimple_parser_node_ACmpleBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpleBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpleBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpleBinop$vtype _jc_soot_jimple_parser_node_ACmpleBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpleBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpleBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpleBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ACmpleBinop.h <==
// public final class soot.jimple.parser.node.ACmpleBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fb62b571c38d6640 soot_jimple_parser_node_ACmpleBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpleBinop_H_
#define _JC_soot_jimple_parser_node_ACmpleBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmple$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpleBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpleBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpleBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpleBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpleBinop$refs	_jc_soot_jimple_parser_node_ACmpleBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpleBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpleBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpleBinop$object	_jc_soot_jimple_parser_node_ACmpleBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpleBinop$vmethods	_jc_soot_jimple_parser_node_ACmpleBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpleBinop$vtable	_jc_soot_jimple_parser_node_ACmpleBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpleBinop$vtype	_jc_soot_jimple_parser_node_ACmpleBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpleBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpleBinop$method$_init$5d04d886763d6058(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_TCmple$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpleBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpleBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TCmple$object *_jc_soot_jimple_parser_node_ACmpleBinop$method$getCmple$62c946aa52c39c95(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpleBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpleBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpleBinop$method$setCmple$47961de99a6cbeff(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_TCmple$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpleBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$getCmple$62c946aa52c39c95;
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$setCmple$47961de99a6cbeff;
extern _jc_method _jc_soot_jimple_parser_node_ACmpleBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpleBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TCmple$object	*(*getCmple$62c946aa52c39c95)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setCmple$47961de99a6cbeff)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *, struct _jc_soot_jimple_parser_node_TCmple$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpleBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpleBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpleBinop$vmethods	soot_jimple_parser_node_ACmpleBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpleBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpleBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpleBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmple$object	*__5fcmple__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpleBinop$refs {
    _jc_soot_jimple_parser_node_ACmpleBinop$sub_refs	soot_jimple_parser_node_ACmpleBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpleBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpleBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpleBinop$sub_nonrefs	soot_jimple_parser_node_ACmpleBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpleBinop$object {
	_jc_soot_jimple_parser_node_ACmpleBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpleBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpleBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpleBinop$vtype _jc_soot_jimple_parser_node_ACmpleBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpleBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpleBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpleBinop_H_ */
